@@ -10,7 +10,8 @@ def addAccis(
         ScriptType: str = None,
         Outputs: str = None,
         EnergyPlus_version: str = None,
-        AdapStand: any = None,
+        TempCtrl: str = None,
+        ComfStand: any = None,
         CAT: any = None,
         ComfMod: any = None,
         HVACmode: any = None,
@@ -26,15 +27,43 @@ def addAccis(
         confirmGen: bool = None):
     """
     Parameters
-    :param ScriptType: The default is None.'vrf' for VRFsystem, 'ex_ac' for ExistingHVAC only with full air-conditioning mode, and 'ex_mm' for ExistingHVAC with mixed-mode..
+    :param ScriptType: The default is None.
+    'vrf_ac' for VRFsystem with full air-conditionin mode, 
+    'vrf_mm' for VRFsystem with mixed-mode, 
+    'ex_ac' for ExistingHVAC only with full air-conditioning mode, 
+    'ex_mm' for ExistingHVAC with mixed-mode.
     :param Outputs: The default is None. Can be 'standard', 'simplified' or 'timestep'.
-    :param EnergyPlus_version: The default is None. Can be 'ep91', 'ep92', 'ep93', 'ep94', 'ep95' or 'ep96'.
-    :param AdapStand: The default is None.
-    (0 = CTE; 1 = EN16798-1; 2 = ASHRAE 55; 3 = JPN)
+    :param EnergyPlus_version: The default is None. Can be '9.1', '9.2', '9.3', '9.4', '9.5', '9.6', '22.1' or '22.2'.
+    :param TempCtrl: The default is None. Can be 'temp' or 'pmv'.
+    :param ComfStand: The default is None.
+        '0 = ESP CTE;
+        '1 = INT EN16798;
+        '2 = INT ASHRAE55;
+        '3 = JPN Rijal;
+        '4 = CHN GBT50785 Cold;
+        '5 = CHN GBT50785 HotMild;
+        '6 = CHN Yang;
+        '7 = IND IMAC C NV;
+        '8 = IND IMAC C MM;
+        '9 = IND IMAC R 7DRM;
+        '10 = IND IMAC R 30DRM;
+        '11 = IND Dhaka;
+        '12 = ROM Udrea;
+        '13 = AUS Williamson;
+        '14 = AUS DeDear;
+        '15 = BRA Rupp NV;
+        '16 = BRA Rupp AC;
+        '17 = MEX Oropeza Arid;
+        '18 = MEX Oropeza DryTropic;
+        '19 = MEX Oropeza Temperate;
+        '20 = MEX Oropeza HumTropic;
     :param CAT: The default is None.
-    (1 = CAT I; 2 = CAT II; 3 = CAT III; 80 = 80% ACCEPT; 90 = 90% ACCEPT)
+    (1 = CAT I; 2 = CAT II; 3 = CAT III; 80 = 80% ACCEPT; 85 = 85% ACCEPT; 90 = 90% ACCEPT)
     :param ComfMod: The default is None.
-    (0 = Static; 1 = OUT-CTE; 2 = OUT-SEN16798/SASHRAE55; 3 = OUT-AEN16798/AASHRAE55)
+    (0 = Static;
+    1 = Adaptive when applicable, otherwise relevant local static model;
+    2 = Adaptive when applicable, otherwise relevant international static model
+    3 = Adaptive when applicable, otherwise horizontal extention of adaptive setpoints)
     :param HVACmode: The default is None.
     (0 = Fully Air-conditioned; 1 = Naturally ventilated; 2 = Mixed Mode)
     :param VentCtrl: The default is None.
@@ -51,14 +80,15 @@ def addAccis(
 
     Exceptions
             DESCRIPTION. EnergyPlus version not supported.
-        Only works for versions between EnergyPlus 9.1 (enter ep91) and
-        EnergyPlus 9.6 (enter ep96).
+        Only works for versions between EnergyPlus 9.1 (enter 9.1) and
+        EnergyPlus 22.2 (enter 22.2).
 
     :return:
     Returns nothing. Output IDFs are generated in the source folder, where input IDFs were located.
     """
     import accim.sim.accim_Main as accim_Main
     from os import listdir, remove
+    import accim
 
     filelist = ([file for file in listdir() if file.endswith('.idf')
                  and not '[' in file])
@@ -68,10 +98,12 @@ def addAccis(
     objArgsDef = (
         ScriptType is not None,
         Outputs is not None,
-        EnergyPlus_version is not None
+        EnergyPlus_version is not None,
+        TempCtrl is not None,
     )
 
-    fullScriptTypeList = ['vrf',
+    fullScriptTypeList = ['vrf_ac',
+                          'vrf_mm',
                           'ex_mm',
                           'ex_ac',
                           ]
@@ -86,37 +118,56 @@ def addAccis(
     ]
 
     fullEPversionsList = [
-        'Ep91',
-        'ep91',
-        'Ep92',
-        'ep92',
-        'Ep93',
-        'ep93',
-        'Ep94',
-        'ep94',
-        'Ep95',
-        'ep95',
-        'Ep96',
-        'ep96'
+        '9.1',
+        '9.2',
+        '9.3',
+        '9.4',
+        '9.5',
+        '9.6',
+        '22.1',
+        '22.2'
+    ]
+
+    fullTempCtrllist = [
+        'temperature',
+        'temp',
+        'pmv'
     ]
 
     if all(objArgsDef):
         pass
     else:
-        ScriptType = input("Enter the ScriptType (for VRFsystem: vrf; for ExistingHVAC with mixed mode: ex_mm; or for ExistingHVAC only with full air-conditioning mode: ex_ac): ")
+        ScriptType = input("Enter the ScriptType (\n"
+                           "for VRFsystem with full air-conditioning mode: vrf_ac;\n"
+                           "for VRFsystem with mixed-mode: vrf_mm;\n"
+                           "for ExistingHVAC with mixed mode: ex_mm;\n"
+                           "for ExistingHVAC with full air-conditioning mode: ex_ac\n"
+                           "): ")
         while ScriptType not in fullScriptTypeList:
-            ScriptType = input("ScriptType was not correct. "
-                               "Please, enter the ScriptType "
-                               "(for VRFsystem: vrf; for ExistingHVAC with mixed mode: ex_mm; or for ExistingHVAC only with full air-conditioning mode: ex_ac): ")
+            ScriptType = input("    ScriptType was not correct. "
+                               "    Enter the ScriptType (\n"
+                               "    for VRFsystem with full air-conditioning mode: vrf_ac;\n"
+                               "    for VRFsystem with mixed-mode: vrf_mm;\n"
+                               "    for ExistingHVAC with mixed mode: ex_mm;\n"
+                               "    for ExistingHVAC with full air-conditioning mode: ex_ac\n"
+                               "    ): ")
         Outputs = input("Enter the Output (standard, simplified or timestep): ")
         while Outputs not in fullOutputsList:
-            Outputs = input("Output was not correct. "
+            Outputs = input("   Output was not correct. "
                             "Please, enter the Output (standard, simplified or timestep): ")
-        EnergyPlus_version = input("Enter the EnergyPlus version (ep91 to ep96): ")
+        EnergyPlus_version = input("Enter the EnergyPlus version (9.1 to 22.2): ")
         while EnergyPlus_version not in fullEPversionsList:
-            EnergyPlus_version = input("EnergyPlus version was not correct. "
-                                       "Please, enter the EnergyPlus version (ep91 to ep96): ")
+            EnergyPlus_version = input("    EnergyPlus version was not correct. "
+                                       "Please, enter the EnergyPlus version (9.1 to 22.2): ")
+        TempCtrl = input('Enter the Temperature Control method (temperature or pmv): ')
+        while TempCtrl not in fullTempCtrllist:
+            TempCtrl = input("  Temperature Control method was not correct. "
+                             "Please, enter the Temperature Control method (temperature or pmv): ")
+
+
     if verboseMode:
+        print('Basic input data:')
+        # print(f'accim version: {accim.__version__}')
         print('ScriptType is: '+ScriptType)
     if ScriptType not in fullScriptTypeList:
         print('Valid ScriptTypes: ')
@@ -138,6 +189,15 @@ def addAccis(
         raise ValueError(EnergyPlus_version + " is not a valid EnergyPlus_version. "
                                               "You must choose a EnergyPlus_version"
                                               "from the list above.")
+    if verboseMode:
+        print('Temperature Control method is: '+TempCtrl)
+    if TempCtrl not in fullTempCtrllist:
+        print('Valid Temperature Control methods: ')
+        print(fullTempCtrllist)
+        raise ValueError(TempCtrl + " is not a valid Temperature Control method. "
+                                              "You must choose a Temperature Control method"
+                                              "from the list above.")
+
     notWorkingIDFs = []
 
     for file in filelist:
@@ -149,6 +209,7 @@ def addAccis(
             filename_temp=file,
             ScriptType=ScriptType,
             EnergyPlus_version=EnergyPlus_version,
+            TempCtrl=TempCtrl,
             verboseMode=verboseMode
         )
 
@@ -157,18 +218,23 @@ def addAccis(
             notWorkingIDFs.append(file)
             continue
 
-        z.setComfFieldsPeople(EnergyPlus_version=EnergyPlus_version, verboseMode=verboseMode)
+        z.setComfFieldsPeople(EnergyPlus_version=EnergyPlus_version, TempCtrl=TempCtrl, verboseMode=verboseMode)
 
-        if ScriptType.lower() == 'vrf':
-            z.addOpTempTherm(verboseMode=verboseMode)
+        if 'vrf' in ScriptType.lower():
+            if TempCtrl.lower() == 'temperature' or TempCtrl.lower() == 'temp':
+                z.addOpTempTherm(verboseMode=verboseMode)
+            elif TempCtrl.lower() == 'pmv':
+                z.setPMVsetpoint(verboseMode=verboseMode)
             z.addBaseSchedules(verboseMode=verboseMode)
             z.setAvailSchOn(verboseMode=verboseMode)
             z.addVRFsystemSch(verboseMode=verboseMode)
             z.addCurveObj(verboseMode=verboseMode)
-            z.addDetHVACobj(EnergyPlus_version=EnergyPlus_version, verboseMode=verboseMode)
-            z.checkVentIsOn(verboseMode=verboseMode)
+            z.addDetHVACobj(EnergyPlus_version=EnergyPlus_version, verboseMode=verboseMode, TempCtrl=TempCtrl)
+            if ScriptType.lower() == 'vrf_mm':
+                z.checkVentIsOn(verboseMode=verboseMode)
             z.addForscriptSchVRFsystem(verboseMode=verboseMode)
         elif 'ex' in ScriptType.lower():
+            # todo check if PMV can work with ex_ac
             z.addForscriptSchExistHVAC(verboseMode=verboseMode)
 
         z.addEMSProgramsBase(ScriptType=ScriptType, verboseMode=verboseMode)
@@ -178,17 +244,24 @@ def addAccis(
         z.addEMSSensorsBase(ScriptType=ScriptType, verboseMode=verboseMode)
         z.addEMSActuatorsBase(ScriptType=ScriptType, verboseMode=verboseMode)
 
-        if ScriptType.lower() == 'vrf':
-            z.addEMSSensorsVRFsystem(verboseMode=verboseMode)
+        if 'vrf' in ScriptType.lower():
+            z.addEMSSensorsVRFsystem(ScriptType=ScriptType, verboseMode=verboseMode)
         elif ScriptType.lower() == 'ex_mm':
             z.addEMSSensorsExisHVAC(verboseMode=verboseMode)
 
         z.addEMSPCMBase(verboseMode=verboseMode)
 
         if Outputs.lower() == 'simplified':
-            z.addSimplifiedOutputVariables(verboseMode=verboseMode)
+            z.addSimplifiedOutputVariables(
+                TempCtrl=TempCtrl,
+                verboseMode=verboseMode
+            )
         elif Outputs.lower() == 'standard':
-            z.addOutputVariablesBase(ScriptType=ScriptType, verboseMode=verboseMode)
+            z.addOutputVariablesBase(
+                ScriptType=ScriptType,
+                TempCtrl=TempCtrl,
+                verboseMode=verboseMode
+            )
 
         if Outputs.lower() == 'timestep':
             z.addOutputVariablesTimestep(verboseMode=verboseMode)
@@ -219,7 +292,7 @@ def addAccis(
         print('''\n=======================START OF OUTPUT IDF FILES GENERATION PROCESS=======================\n''')
 
     args_needed_mm = (
-        AdapStand is not None,
+        ComfStand is not None,
         CAT is not None,
         ComfMod is not None,
         HVACmode is not None,
@@ -227,15 +300,16 @@ def addAccis(
     )
 
     args_needed_ac = (
-        AdapStand is not None,
+        ComfStand is not None,
         CAT is not None,
         ComfMod is not None,
     )
-    if ScriptType.lower() == 'vrf' or ScriptType.lower() == 'ex_mm':
+    if ScriptType.lower() == 'vrf_mm' or ScriptType.lower() == 'ex_mm':
         if all(args_needed_mm):
             z.genIDF(
                 ScriptType=ScriptType,
-                AdapStand=AdapStand,
+                TempCtrl=TempCtrl,
+                ComfStand=ComfStand,
                 CAT=CAT,
                 ComfMod=ComfMod,
                 HVACmode=HVACmode,
@@ -251,13 +325,19 @@ def addAccis(
                 confirmGen=confirmGen
                 )
         else:
-            z.inputData(ScriptType=ScriptType)
-            z.genIDF(ScriptType=ScriptType)
-    elif ScriptType.lower() == 'ex_ac':
+            z.inputData(
+                ScriptType=ScriptType,
+            )
+            z.genIDF(
+                ScriptType=ScriptType,
+                TempCtrl=TempCtrl,
+            )
+    elif ScriptType.lower() == 'ex_ac' or ScriptType.lower() == 'vrf_ac':
         if all(args_needed_ac):
             z.genIDF(
                 ScriptType=ScriptType,
-                AdapStand=AdapStand,
+                TempCtrl=TempCtrl,
+                ComfStand=ComfStand,
                 CAT=CAT,
                 ComfMod=ComfMod,
                 HVACmode=[0],
@@ -273,8 +353,13 @@ def addAccis(
                 confirmGen=confirmGen
                 )
         else:
-            z.inputData(ScriptType=ScriptType)
-            z.genIDF(ScriptType=ScriptType)
+            z.inputData(
+                ScriptType=ScriptType,
+            )
+            z.genIDF(
+                ScriptType=ScriptType,
+                TempCtrl=TempCtrl,
+            )
 
     if verboseMode:
         print('''\n=======================END OF OUTPUT IDF FILES GENERATION PROCESS=======================\n''')
